==> nextcloud-25.0.4.tgz: nextcloud/apps/password_policy/l10n/nl.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Wachtwoord verlopen, gebruik 'wachtwoord vergeten' om te herstellen",
    "Password must not have been used recently before." : "Wachtwoord mag niet al eerder gebruikt zijn",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Het wachtwoord behoort tot de 1.000.000 meest gebruikte wachtwoorden. Maak het meer uniek.",
    "Password is present in compromised password list. Please choose a different password." : "Het wachtwoord is aanwezig in de lijst met gecompromitteerde wachtwoorden. Kies een ander.",
    "Password needs to be at least %s characters long." : "Het wachtwoord moet minimaal %s tekens lang zijn.",
    "Password needs to contain at least one numeric character." : "Het wachtwoord moet minimaal één cijfer bevatten.",
    "Password needs to contain at least one special character." : "Het wachtwoord moet minimaal één speciaal teken bevatten.",
    "Password needs to contain at least one lower and one upper case character." : "Het wachtwoord moet minimaal één kleine letter en één hoofdletter bevatten.",
    "Password policy" : "Wachtwoordenbeleid",
    "Allows admins to configure a password policy" : "Staat toe dat beheerders een wachtwoordenbeleid configureren",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Sta beheerder toe om bepaalde randvoorwaarden te definiëren voor het wachtwoord. B.v. minimum wachtwoordlengte",
    "Saved" : "Opgeslagen",
    "Minimum password length" : "Minimale wachtwoordsterkte",
    "User password history" : "Wachtwoordhistorie gebruiker",
    "Number of days until user password expires" : "Aantal dagen tot het wachtwoord van de gebruiker verloopt",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Aantal inlogpogingen voordat het gebruikersaccount wordt geblokkeerd (0 voor onbeperkt)",
    "Forbid common passwords" : "Verbied algemene wachtwoorden",
    "Enforce upper and lower case characters" : "Hoofdletters en kleine letters verplichten",
    "Enforce numeric characters" : "Cijfers verplichten",
    "Enforce special characters" : "Speciale tekens verplichten",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Controleer het wachtwoord met de lijst van gelekte wachtwoorden van haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Deze controle maakt een hash van het wachtwoord en verstuurd de eerste 5 tekens van deze hash naar de haveibeenpwned.com API om een lijst op te halen met al de hashes die ook daarmee beginnen. Daarna wordt deze lijst tegen de Nexcloud installatie gehouden om te controleren of de wachtwoord hash als resultaat terugkomt.",
    "Unknown error" : "Onbekende fout",
    "Minimal length has to be a non negative number" : "Minimale lengte moet een niet-negatief getal zijn",
    "History size has to be a non negative number" : "Geschiedenisaantal moet een niet-negatief getal zijn",
    "Expiration days have to be a non negative number" : "Vervaldagen moet een niet-negatief getal zijn",
    "Maximum login attempts have to be a non negative number" : "Maximum aantal inlogpogingen moet een niet-negatief getal zijn"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.2.tgz: nextcloud/apps/password_policy/l10n/nl.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Wachtwoord verlopen, gebruik 'wachtwoord vergeten' om te herstellen",
    "Password must not have been used recently before." : "Wachtwoord mag niet al eerder gebruikt zijn",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Het wachtwoord behoort tot de 1.000.000 meest gebruikte wachtwoorden. Maak het meer uniek.",
    "Password is present in compromised password list. Please choose a different password." : "Het wachtwoord is aanwezig in de lijst met gecompromitteerde wachtwoorden. Kies een ander.",
    "Password needs to be at least %s characters long." : "Het wachtwoord moet minimaal %s tekens lang zijn.",
    "Password needs to contain at least one numeric character." : "Het wachtwoord moet minimaal één cijfer bevatten.",
    "Password needs to contain at least one special character." : "Het wachtwoord moet minimaal één speciaal teken bevatten.",
    "Password needs to contain at least one lower and one upper case character." : "Het wachtwoord moet minimaal één kleine letter en één hoofdletter bevatten.",
    "Password policy" : "Wachtwoordenbeleid",
    "Allows admins to configure a password policy" : "Staat toe dat beheerders een wachtwoordenbeleid configureren",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Sta beheerder toe om bepaalde randvoorwaarden te definiëren voor het wachtwoord. B.v. minimum wachtwoordlengte",
    "Minimum password length" : "Minimale wachtwoordsterkte",
    "User password history" : "Wachtwoordhistorie gebruiker",
    "Number of days until user password expires" : "Aantal dagen tot het wachtwoord van de gebruiker verloopt",
    "Number of login attempts before the user account is blocked (0 for no limit)" : "Aantal inlogpogingen voordat het gebruikersaccount wordt geblokkeerd (0 voor onbeperkt)",
    "Forbid common passwords" : "Verbied algemene wachtwoorden",
    "Enforce upper and lower case characters" : "Hoofdletters en kleine letters verplichten",
    "Enforce numeric characters" : "Cijfers verplichten",
    "Enforce special characters" : "Speciale tekens verplichten",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Controleer het wachtwoord met de lijst van gelekte wachtwoorden van haveibeenpwned.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Deze controle maakt een hash van het wachtwoord en verstuurd de eerste 5 tekens van deze hash naar de haveibeenpwned.com API om een lijst op te halen met al de hashes die ook daarmee beginnen. Daarna wordt deze lijst tegen de Nexcloud installatie gehouden om te controleren of de wachtwoord hash als resultaat terugkomt.",
    "Unknown error" : "Onbekende fout",
    "Minimal length has to be a non negative number" : "Minimale lengte moet een niet-negatief getal zijn",
    "History size has to be a non negative number" : "Geschiedenisaantal moet een niet-negatief getal zijn",
    "Expiration days have to be a non negative number" : "Vervaldagen moet een niet-negatief getal zijn",
    "Maximum login attempts have to be a non negative number" : "Maximum aantal inlogpogingen moet een niet-negatief getal zijn",
    "Settings saved" : "Instellingen opgeslagen",
    "Error while saving settings" : "Probleem tijdens het opslaan van instellingen",
    "Saved" : "Opgeslagen",
    "Error while saving" : "Fout bij opslaan"
},
"nplurals=2; plural=(n != 1);");
